summaryrefslogtreecommitdiff
path: root/catlfish-dev
diff options
context:
space:
mode:
Diffstat (limited to 'catlfish-dev')
-rwxr-xr-xcatlfish-dev/start.sh9
1 files changed, 6 insertions, 3 deletions
diff --git a/catlfish-dev/start.sh b/catlfish-dev/start.sh
index 3a982fb..bef885e 100755
--- a/catlfish-dev/start.sh
+++ b/catlfish-dev/start.sh
@@ -31,11 +31,14 @@ case $role in
;;
merge)
# Catlfish version is included in filename of archive and
# filename in that archive. Example: lib/catlfish-0.6.0.ez
# contains catlfish-0.6.0.
ver=$(ls $erlbase/lib/catlfish-*.ez | sed 's/.*catlfish-\(.*\)\.ez/\1/1')
ERL_LIBS=$erlbase/lib/catlfish-${ver}.ez/catlfish-${ver}
+ ver=$(ls $erlbase/lib/plop-*.ez | sed 's/.*plop-\(.*\)\.ez/\1/1')
+ ERL_LIBS=$ERL_LIBS:$erlbase/lib/plop-${ver}.ez/plop-${ver}/ebin
ERL_LIBS=$ERL_LIBS:$erlbase/lib/lager-2.1.1.ez/lager-2.1.1
export ERL_LIBS
@@ -31,11 +31,14 @@ case $role in
;;
merge)
- # Catlfish version is included in filename of archive and
- # filename in that archive. Example: lib/catlfish-0.6.0.ez
- # contains catlfish-0.6.0.
+ # Catlfish and plop versions are included in filename of
+ # archive file and in the filename within the
+ # archive. Example: lib/catlfish-0.6.0.ez contains
+ # catlfish-0.6.0.
ver=$(ls $erlbase/lib/catlfish-*.ez | sed 's/.*catlfish-\(.*\)\.ez/\1/1')
ERL_LIBS=$erlbase/lib/catlfish-${ver}.ez/catlfish-${ver}